@@ -38,6 +38,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifdef Q_OS_OSX
 #include <QFileOpenEvent>
 #endif
+#include <QJsonArray>
+#include <QJsonObject>
 
 // KDE
 #include <KActionCategory>
@@ -55,8 +57,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KUrlComboBox>
 #include <KUrlNavigator>
 #include <KToolBar>
+#include <KToolBarPopupAction>
 #include <KXMLGUIFactory>
 #include <KDirLister>
+#ifdef KF5Purpose_FOUND
+#include <PurposeWidgets/Menu>
+#include <Purpose/AlternativesModel>
+#endif
 
 // Local
 #include "configdialog.h"
@@ -195,6 +202,10 @@ struct MainWindow::Private
     QAction * mToggleSlideShowAction;
     KToggleAction* mShowMenuBarAction;
     KToggleAction* mShowStatusBarAction;
+#ifdef KF5Purpose_FOUND
+    Purpose::Menu* mShareMenu;
+    KToolBarPopupAction* mShareAction;
+#endif
 #ifdef KIPI_FOUND
     KIPIExportAction* mKIPIExportAction;
 #endif
@@ -504,7 +515,14 @@ struct MainWindow::Private
 
 #ifdef KIPI_FOUND
         mKIPIExportAction = new KIPIExportAction(q);
-        actionCollection->addAction("kipi_export", mKIPIExportAction);
+#endif
+
+#ifdef KF5Purpose_FOUND
+        mShareAction = new KToolBarPopupAction(QIcon::fromTheme("document-share"), i18nc("@action Share images", "Share"), q);
+        mShareAction->setDelayed(false);
+        actionCollection->addAction("share", mShareAction);
+        mShareMenu = new Purpose::Menu(q);
+        mShareAction->setMenu(mShareMenu);
 #endif
     }
 
@@ -708,6 +726,20 @@ struct MainWindow::Private
         actionCollection->action("file_save")->setEnabled(canSave && isModified);
         actionCollection->action("file_save_as")->setEnabled(canSave);
         actionCollection->action("file_print")->setEnabled(isRasterImage);
+
+#ifdef KF5Purpose_FOUND
+        if (url.isEmpty()) {
+            mShareAction->setEnabled(false);
+        } else {
+            mShareAction->setEnabled(true);
+            mShareMenu->model()->setInputData(QJsonObject{
+                { QStringLiteral("mimeType"), MimeTypeUtils::urlMimeType(url) },
+                { QStringLiteral("urls"), QJsonArray{url.toString()} }
+            });
+            mShareMenu->model()->setPluginType( QStringLiteral("Export") );
+            mShareMenu->reload();
+        }
+#endif
     }
 
     bool sideBarVisibility() const
@@ -869,8 +901,10 @@ MainWindow::MainWindow()
                                           d->mGoToPreviousAction, d->mGoToNextAction, this);
 #endif
 
-#ifdef GWENVIEW_SEMANTICINFO_BACKEND_NONE
+
     auto* ratingMenu = static_cast<QMenu*>(guiFactory()->container("rating", this));
+    ratingMenu->setIcon(QIcon::fromTheme(QStringLiteral("rating-unrated")));
+#ifdef GWENVIEW_SEMANTICINFO_BACKEND_NONE
     if (ratingMenu) {
         ratingMenu->menuAction()->setVisible(false);
     }
@@ -893,7 +927,7 @@ MainWindow::MainWindow()
 
 MainWindow::~MainWindow()
 {
-    if (GwenviewConfig::deleteThumbnailCacheOnExit()) {
+    if (GwenviewConfig::lowResourceUsageMode()) {
         QDir dir(ThumbnailProvider::thumbnailBaseDir());
         if (dir.exists()) {
             dir.removeRecursively();
