@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include <statusbartoolbutton.moc>
+#include <statusbartoolbutton.h>
 
 // Qt
 #include <QAction>
@@ -28,7 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QToolButton>
 
 // KDE
-#include <KLocale>
+#include <KLocalizedString>
 
 namespace Gwenview
 {
@@ -103,7 +103,7 @@ void StatusBarToolButton::paintEvent(QPaintEvent* event)
     // messages so that translators can use Transcript for custom removal.
     // """
     if (!actions().isEmpty()) {
-        QAction* action = actions().first();
+        QAction* action = actions().constFirst();
         setToolTip(i18nc("@info:tooltip of custom toolbar button", "%1", action->toolTip()));
     }
 }
