@@ -64,7 +64,7 @@ void ContextManagerTest::testRemove()
     manager.selectionModel()->setCurrentIndex(dirModel.index(1, 0), QItemSelectionModel::Select);
 
     // Remove "b", `manager` should select "c"
-    sandBox.remove("b");
+    sandBox.remove(QStringLiteral("b"));
     dirModel.dirLister()->updateDirectory(dirUrl);
     while (dirModel.rowCount() == 3) {
         QTest::qWait(100);
@@ -72,10 +72,10 @@ void ContextManagerTest::testRemove()
 
     QModelIndex currentIndex = manager.selectionModel()->currentIndex();
     QCOMPARE(currentIndex.row(), 1);
-    QCOMPARE(currentIndex.data(Qt::DisplayRole).toString(), QString("c"));
+    QCOMPARE(currentIndex.data(Qt::DisplayRole).toString(), QStringLiteral("c"));
 
     // Remove "c", `manager` should select "a"
-    sandBox.remove("c");
+    sandBox.remove(QStringLiteral("c"));
     dirModel.dirLister()->updateDirectory(dirUrl);
     while (dirModel.rowCount() == 2) {
         QTest::qWait(100);
@@ -83,7 +83,7 @@ void ContextManagerTest::testRemove()
 
     currentIndex = manager.selectionModel()->currentIndex();
     QCOMPARE(currentIndex.row(), 0);
-    QCOMPARE(currentIndex.data(Qt::DisplayRole).toString(), QString("a"));
+    QCOMPARE(currentIndex.data(Qt::DisplayRole).toString(), QStringLiteral("a"));
 }
 
 void ContextManagerTest::testInvalidDirUrl()
@@ -97,7 +97,7 @@ void ContextManagerTest::testInvalidDirUrl()
             setAutoErrorHandlingEnabled(false, nullptr);
         }
 
-        bool openUrl(const QUrl &url, OpenUrlFlags flags = NoFlags) Q_DECL_OVERRIDE
+        bool openUrl(const QUrl &url, OpenUrlFlags flags = NoFlags) override
         {
             mOpenUrlCalled = true;
             return KDirLister::openUrl(url, flags);
